@@ -25,6 +25,9 @@
 
 #include <QPainter>
 #include <QPainterPath>
+
+#include <QLinearGradient>
+
 #include <QMouseEvent>
 #include <QWheelEvent>
 
@@ -117,23 +120,37 @@ void synthv1widget_wave::paintEvent ( QPaintEvent *pPaintEvent )
 
 	const QPalette& pal = palette();
 	const bool bDark = (pal.window().color().value() < 0x7f);
-	const QColor& rgbLite = (isEnabled()
-		? (bDark ? Qt::darkYellow : Qt::yellow) : pal.mid().color());
-    const QColor& rgbDark = pal.window().color().darker(180);
+	const QColor& rgbLite = (isEnabled() ? Qt::yellow : pal.mid().color());
+	const QColor& rgbDark = pal.window().color().darker();
 
 	painter.fillRect(rect, rgbDark);
 
-	painter.setPen(bDark ? pal.mid().color() : pal.midlight().color());
+	painter.setPen(pal.mid().color());
 	painter.drawLine(w2, 0, w2, h);
 	painter.drawLine(0, h2, w, h2);
 
+	QColor rgbLite1(rgbLite);
+	QColor rgbDrop1(Qt::black);
+	rgbLite1.setAlpha(bDark ? 120 : 180);
+	rgbDrop1.setAlpha(80);
+
+	QLinearGradient grad(0, 0, w << 1, h << 1);
+	grad.setColorAt(0.0f, rgbLite1.darker(bDark ? 200 : 160));
+	grad.setColorAt(1.0f, rgbDrop1);
+
 	painter.setRenderHint(QPainter::Antialiasing, true);
 
-	painter.setPen(QPen(rgbLite.darker(), 2));
 	path.translate(+1, +1);
+	painter.setPen(QPen(rgbDrop1, 2));
+	painter.setBrush(Qt::transparent);
 	painter.drawPath(path);
-	painter.setPen(QPen(rgbLite, 2));
 	path.translate(-1, -1);
+	painter.setPen(QPen(rgbLite1, 2));
+	painter.drawPath(path);
+
+	path.lineTo(1, h2);
+	painter.setPen(Qt::transparent);
+	painter.setBrush(grad);
 	painter.drawPath(path);
 
 	painter.setRenderHint(QPainter::Antialiasing, false);
